import { Identifiable, Internship, Mentor } from "@/data";
import { OneWayTransformer } from "@/serialization";
import { Nullable } from "@/helpers";

export interface InternshipRegistrationUpdateCompany {
    id: string,
    branchOffice: Identifiable,
}

export interface InternshipRegistrationUpdate {
    company: InternshipRegistrationUpdateCompany,
    start: string,
    end: string,
    type: number,
    mentor: Mentor,
}

export const internshipRegistrationUpdateTransformer: OneWayTransformer<Nullable<Internship>, Nullable<InternshipRegistrationUpdate>> = {
    transform(subject: Nullable<Internship>, context?: unknown): Nullable<InternshipRegistrationUpdate> {
        return {
            start: subject?.startDate?.toISOString() || null,
            end: subject?.endDate?.toISOString() || null,
            type: parseInt(subject?.type?.id || "0"),
            mentor: subject.mentor,
            company: {
                id: subject?.company?.id as string,
                branchOffice: {
                    id: subject?.office?.id
                },
            }
        }
    }
}
